==> dokuwiki-2013.05.10.tgz: dokuwiki/inc/lang/ca-valencia/lang.php <==
<?php
/**
 * valencian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Bernat Arlandis i Mañó <berarma@ya.com>
 * @author Bernat Arlandis <berarma@llenguaitecnologia.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '“';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = 'Editar esta pàgina';
$lang['btn_source']            = 'Mostrar font';
$lang['btn_show']              = 'Mostrar pàgina';
$lang['btn_create']            = 'Crear esta pàgina';
$lang['btn_search']            = 'Buscar';
$lang['btn_save']              = 'Guardar';
$lang['btn_preview']           = 'Vista prèvia';
$lang['btn_top']               = 'Tornar dalt';
$lang['btn_newer']             = '<< més recents';
$lang['btn_older']             = 'manco recents >>';
$lang['btn_revs']              = 'Versions antigues';
$lang['btn_recent']            = 'Canvis recents';
$lang['btn_upload']            = 'Pujar';
$lang['btn_cancel']            = 'Cancelar';
$lang['btn_index']             = 'Índex';
$lang['btn_secedit']           = 'Editar';
$lang['btn_login']             = 'Iniciar sessió';
$lang['btn_logout']            = 'Tancar sessió';
$lang['btn_admin']             = 'Administrar';
$lang['btn_update']            = 'Actualisar';
$lang['btn_delete']            = 'Borrar';
$lang['btn_back']              = 'Arrere';
$lang['btn_backlink']          = 'Vínculs remitents';
$lang['btn_backtomedia']       = 'Tornar a la selecció d\'archius de mijos';
$lang['btn_subscribe']         = 'Subscriure\'s a la pàgina';
$lang['btn_unsubscribe']       = 'Desubscriure\'s de la pàgina';
$lang['btn_profile']           = 'Actualisar perfil';
$lang['btn_reset']             = 'Reiniciar';
$lang['btn_draft']             = 'Editar borrador';
$lang['btn_recover']           = 'Recuperar borrador';
$lang['btn_draftdel']          = 'Borrar borrador';
$lang['btn_revert']            = 'Recuperar';
$lang['btn_register']          = 'Registrar-se';
$lang['loggedinas']            = 'Sessió de';
$lang['user']                  = 'Nom d\'usuari';
$lang['pass']                  = 'Contrasenya';
$lang['newpass']               = 'Contrasenya nova';
$lang['oldpass']               = 'Confirmar la contrasenya actual';
$lang['passchk']               = 'una atra volta';
$lang['remember']              = 'Recorda\'m';
$lang['fullname']              = 'Nom complet';
$lang['email']                 = 'Correu electrònic';
$lang['profile']               = 'Perfil d\'usuari';
$lang['badlogin']              = 'Disculpe, pero el nom d\'usuari o la contrasenya són incorrectes.';
$lang['minoredit']             = 'Canvis menors';
$lang['draftdate']             = 'Borrador gravat el';
$lang['nosecedit']             = 'La pàgina ha canviat mentres tant, l\'informació de la secció no estava al dia, s\'ha carregat la pàgina sancera.';
$lang['regmissing']            = 'Disculpe, pero deu omplir tots els camps.';
$lang['reguexists']            = 'Disculpe, pero ya existix un usuari en este nom.';
$lang['regsuccess']            = 'S\'ha creat l\'usuari i se li ha enviat la contrasenya per correu electrònic.';
$lang['regsuccess2']           = 'S\'ha creat l\'usuari.';
$lang['regmailfail']           = 'Pareix que ha hagut un erro enviant el correu en la contrasenya. ¡Per favor, contacte en l\'administrador!';
$lang['regbadmail']            = 'La direcció de correu no pareix vàlida - contacte en l\'administrador si pensa que és deu a un erro nostre';
$lang['regbadpass']            = 'Les dos contrasenyes que ha donat no són idèntiques, per favor, torne a intentar-ho.';
$lang['regpwmail']             = 'La seua contrasenya de DokuWiki';
$lang['reghere']               = '¿Encara no té un conte? Cree-se\'n un';
$lang['profna']                = 'Este wiki no li permet modificar el perfil';
$lang['profnochange']          = 'Sense canvis, no hi ha res que fer.';
$lang['profnoempty']           = 'No es permet deixar el nom o la direcció de correu buits.';
$lang['profchanged']           = 'Perfil de l\'usuari actualisat.';
$lang['pwdforget']             = '¿Ha oblidat la contrasenya? Demane\'n una nova';
$lang['resendna']              = 'Este wiki no permet reenviar la contrasenya.';
$lang['resendpwdmissing']      = 'Disculpe, pero deu omplir tots els camps.';
$lang['resendpwdnouser']       = 'Disculpe, pero no trobem ad est usuari en la base de senyes.';
$lang['resendpwdbadauth']      = 'Disculpe, pero este còdic d\'autenticació no es vàlit. Verifique que haja utilisat el víncul de confirmació sancer.';
$lang['resendpwdconfirm']      = 'Li hem enviat un víncul de confirmació al correu.';
$lang['resendpwdsuccess']      = 'Se li ha enviat una nova contrasenya per correu electrònic.';
$lang['license']               = 'Excepte quan s\'indique una atra cosa, el contingut d\'este wiki està llicenciat baix la següent llicència:';
$lang['licenseok']             = 'Nota: a l\'editar esta pàgina accepta llicenciar el seu contingut baix la següent llicència:';
$lang['searchmedia']           = 'Buscar nom d\'archiu:';
$lang['searchmedia_in']        = 'Buscar en %s';
$lang['txt_upload']            = 'Seleccione l\'archiu que vol pujar';
$lang['txt_filename']          = 'Enviar com (opcional)';
$lang['txt_overwrt']           = 'Sobreescriure archius existents';
$lang['lockedby']              = 'Actualment bloquejat per';
$lang['lockexpire']            = 'El bloqueig venç a les';
$lang['js']['willexpire']            = 'El seu bloqueig per a editar esta pàgina vencerà en un minut.\nPer a evitar conflictes utilise el botó de vista prèvia i reiniciarà el contador.';
$lang['js']['notsavedyet']     = 'Els canvis no guardats es perdran.\n¿Segur que vol continuar?';
$lang['rssfailed']             = 'Ha ocorregut un erro al solicitar este canal: ';
$lang['nothingfound']          = 'No s\'ha trobat res.';
$lang['mediaselect']           = 'Archius de mijos';
$lang['fileupload']            = 'Enviar archius de mijos';
$lang['uploadsucc']            = 'Enviament correcte';
$lang['uploadfail']            = 'Enviament fallit. ¿Potser no tinga els permissos necessaris?';
$lang['uploadwrong']           = 'Enviament denegat. ¡Esta extensió d\'archiu està prohibida!';
$lang['uploadexist']           = 'L\'archiu ya existix. No s\'ha fet res.';
$lang['uploadbadcontent']      = 'El contingut enviat no coincidix en l\'extensió de l\'archiu %s';
$lang['uploadspam']            = 'L\'enviament ha segut bloquejat per la llista anti-spam.';
$lang['uploadxss']             = 'L\'enviament ha segut bloquejat per ser possiblement perillós.';
$lang['uploadsize']            = 'L\'archiu enviat és massa gran. (màx. %s)';
$lang['deletesucc']            = 'S\'ha borrat l\'archiu "%s".';
$lang['deletefail']            = 'No s\'ha pogut borrar "%s" - comprove els permissos.';
$lang['mediainuse']            = 'L\'archiu "%s" no s\'ha borrat - encara s\'està utilisant.';
$lang['namespaces']            = 'Espais de noms';
$lang['mediafiles']            = 'Archius disponibles en';
$lang['js']['searchmedia']     = 'Buscar archius';
$lang['js']['keepopen']        = 'Mantindre la finestra oberta al seleccionar';
$lang['js']['hidedetails']     = 'Ocultar detalls';
$lang['js']['nosmblinks']      = 'Els vínculs a recursos compartits de Windows només funcionen en Microsoft Internet Explorer. No obstant, es poden copiar i apegar.';
$lang['js']['linkwiz']         = 'Assistent de vínculs';
$lang['js']['linkto']          = 'Vincular a:';
$lang['js']['del_confirm']     = '¿Realment vol borrar el(s) ítem(s) seleccionat(s)?';
$lang['mediausage']            = 'Utilise la següent sintaxis per a referenciar est archiu:';
$lang['mediaview']             = 'Vore l\'archiu original';
$lang['mediaroot']             = 'base';
$lang['mediaupload']           = 'Enviar un archiu a l\'espai de noms actual. Per a crear sub-espais, afigga\'ls separats per dos punts davant del nom de l\'archiu que pose en "Enviar com".';
$lang['mediaextchange']        = '¡Extensió de l\'archiu canviada de .%s a .%s!';
$lang['reference']             = 'Referències per a';
$lang['ref_inuse']             = 'No es pot borrar l\'archiu perque encara s\'utilisa en les següents pàgines:';
$lang['ref_hidden']            = 'Algunes referències estan en pàgines que no té permissos per a vore';
$lang['hits']                  = 'Encerts';
$lang['quickhits']             = 'Noms de pàgines coincidents';
$lang['toc']                   = 'Taula de continguts';
$lang['current']               = 'Actual';
$lang['yours']                 = 'La seua versió';
$lang['diff']                  = 'Mostrar diferències en la versió actual';
$lang['diff2']                 = 'Mostrar diferències entre versions';
$lang['line']                  = 'Llínea';
$lang['breadcrumb']            = 'Traça';
$lang['youarehere']            = 'Vosté està ací';
$lang['lastmod']               = 'Última modificació el';
$lang['by']                    = 'per';
$lang['deleted']               = 'borrat';
$lang['created']               = 'creat';
$lang['restored']              = 'restaurada l\'última versió (%s)';
$lang['external_edit']         = 'edició externa';
$lang['summary']               = 'Editar sumari';
$lang['noflash']               = 'Necessita el <a href="http://www.adobe.com/products/flashplayer/">plúgin d\'Adobe Flash</a> per a vore este contingut.';
$lang['download']              = 'Descarregar un tros';
$lang['mail_newpage']          = 'pàgina afegida:';
$lang['mail_changed']          = 'pàgina canviada:';
$lang['mail_new_user']         = 'Usuari nou:';
$lang['mail_upload']           = 'archiu enviat:';
$lang['qb_bold']               = 'Negreta';
$lang['qb_italic']             = 'Itàlica';
$lang['qb_underl']             = 'Subrallat';
$lang['qb_code']               = 'Còdic';
$lang['qb_strike']             = 'Tachat';
$lang['qb_h1']                 = 'Titular de nivell 1';
$lang['qb_h2']                 = 'Titular de nivell 2';
$lang['qb_h3']                 = 'Titular de nivell 3';
$lang['qb_h4']                 = 'Titular de nivell 4';
$lang['qb_h5']                 = 'Titular de nivell 5';
$lang['qb_h']                  = 'Titular';
$lang['qb_hs']                 = 'Triar titular';
$lang['qb_hplus']              = 'Titular superior';
$lang['qb_hminus']             = 'Titular inferior';
$lang['qb_hequal']             = 'Titular al mateix nivell';
$lang['qb_link']               = 'Víncul intern';
$lang['qb_extlink']            = 'Víncul extern';
$lang['qb_hr']                 = 'Llínea horisontal';
$lang['qb_ol']                 = 'Llista numerada';
$lang['qb_ul']                 = 'Llista ';
$lang['qb_media']              = 'Afegir imàgens i atres archius';
$lang['qb_sig']                = 'Afegir firma';
$lang['qb_smileys']            = 'Smileys';
$lang['qb_chars']              = 'Caràcters especials';
$lang['upperns']               = 'anar a l\'espai de noms superior';
$lang['admin_register']        = 'Afegir nou usuari';
$lang['metaedit']              = 'Editar meta-senyes';
$lang['metasaveerr']           = 'Erro escrivint meta-senyes';
$lang['metasaveok']            = 'Meta-senyes guardades';
$lang['img_backto']            = 'Tornar a';
$lang['img_title']             = 'Títul';
$lang['img_caption']           = 'Subtítul';
$lang['img_date']              = 'Data';
$lang['img_fname']             = 'Nom de l\'archiu';
$lang['img_fsize']             = 'Tamany';
$lang['img_artist']            = 'Fotógraf';
$lang['img_copyr']             = 'Copyright';
$lang['img_format']            = 'Format';
$lang['img_camera']            = 'Càmara';
$lang['img_keywords']          = 'Paraules clau';
$lang['subscribe_success']     = '%s afegit a la llista de subscripció per a %s';
$lang['subscribe_error']       = 'Erro afegint a %s a la llista de subscripció per a %s';
$lang['subscribe_noaddress']   = 'No hi ha cap direcció associada a la sessió, no es pot subscriure';
$lang['unsubscribe_success']   = '%s borrat de la llista de subscripció per a %s';
$lang['unsubscribe_error']     = 'Erro borrant a %s de la llista de subscripció per a %s';
$lang['authmodfailed']         = 'Mala configuració de l\'autenticació d\'usuari. Per favor, informe a l\'administrador del Wiki.';
$lang['authtempfail']          = 'L\'autenticació d\'usuaris està desactivada temporalment. Si la situació persistix, per favor, informe a l\'administrador del Wiki.';
$lang['i_chooselang']          = 'Trie l\'idioma';
$lang['i_installer']           = 'Instalador de DokuWiki';
$lang['i_wikiname']            = 'Nom del Wiki';
$lang['i_enableacl']           = 'Activar ACL (recomanat)';
$lang['i_superuser']           = 'Super-usuari';
$lang['i_problems']            = 'L\'instalador ha trobat els problemes mostrats més avall. No pot continuar fins que no els arregle.';
$lang['i_modified']            = 'Per raons de seguritat, este procés només funcionarà en una instalació nova i verge de DokuWiki.
Deuria tornar a extraure els archius del paquet que ha descarregat o consultar les
<a href="http://dokuwiki.org/install">instruccions d\'instalació de Dokuwiki</a> completes';
$lang['i_funcna']              = 'La funció de PHP <code>%s</code> no està disponible. ¿Pot ser que el seu proveïdor d\'hostage l\'haja desactivada per algun motiu?';
$lang['i_phpver']              = 'La versió de PHP <code>%s</code> és menor que
la <code>%s</code> que es necessita. Necessita actualisar PHP.';
$lang['i_permfail']            = 'DokuWiki no pot escriure en <code>%s</code>. ¡Necessita arreglar els permissos d\'este directori!';
$lang['i_confexists']          = '<code>%s</code> ya existix';
$lang['i_writeerr']            = 'No es pot crear <code>%s</code>. Haurà de comprovar els permissos del directori/archiu i crear manualment l\'archiu.';
$lang['i_badhash']             = 'dokuwiki.php substituït o modificat (hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - valor illegal o buit';
$lang['i_success']             = 'La configuració ha finalisat correctament. Ya pot borrar l\'archiu install.php. Passe al
<a href="doku.php?id=wiki:welcome">nou DokuWiki</a>.';
$lang['i_failure']             = 'Han aparegut alguns erros escrivint els archius de configuració. Deurà arreglar-los manualment abans de que
puga utilisar el <a href="doku.php?id=wiki:welcome">nou DokuWiki</a>.';
$lang['i_policy']              = 'Política inicial ACL';
$lang['i_pol0']                = 'Wiki obert (llegir, escriure i enviar tots)';
$lang['i_pol1']                = 'Wiki públic (llegir tots, escriure i enviar només usuaris registrats)';
$lang['i_pol2']                = 'Wiki tancat (llegir, escriure i enviar només usuaris registrats)';
$lang['i_retry']               = 'Reintentar';
$lang['recent_global']         = 'Està veent els canvis dins de l\'espai de noms <b>%s</b>. També pot <a href="%s">vore els canvis recents en el wiki sancer</a>.';
$lang['years']                 = 'fa %d anys';
$lang['months']                = 'fa %d mesos';
$lang['weeks']                 = 'fa %s semanes';
$lang['days']                  = 'fa %d dies';
$lang['hours']                 = 'fa %d hores';
$lang['minutes']               = 'fa %d minuts';
$lang['seconds']               = 'fa %d segons';

==> dokuwiki-2016.06.26a.tgz: dokuwiki/inc/lang/ca-valencia/lang.php <==
<?php
/**
 * valencian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Bernat Arlandis i Mañó <berarma@ya.com>
 * @author Bernat Arlandis <berarma@llenguaitecnologia.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '“';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = 'Editar esta pàgina';
$lang['btn_source']            = 'Mostrar font';
$lang['btn_show']              = 'Mostrar pàgina';
$lang['btn_create']            = 'Crear esta pàgina';
$lang['btn_search']            = 'Buscar';
$lang['btn_save']              = 'Guardar';
$lang['btn_preview']           = 'Vista prèvia';
$lang['btn_top']               = 'Tornar dalt';
$lang['btn_newer']             = '<< més recents';
$lang['btn_older']             = 'manco recents >>';
$lang['btn_revs']              = 'Versions antigues';
$lang['btn_recent']            = 'Canvis recents';
$lang['btn_upload']            = 'Pujar';
$lang['btn_cancel']            = 'Cancelar';
$lang['btn_index']             = 'Índex';
$lang['btn_secedit']           = 'Editar';
$lang['btn_login']             = 'Iniciar sessió';
$lang['btn_logout']            = 'Tancar sessió';
$lang['btn_admin']             = 'Administrar';
$lang['btn_update']            = 'Actualisar';
$lang['btn_delete']            = 'Borrar';
$lang['btn_back']              = 'Arrere';
$lang['btn_backlink']          = 'Vínculs remitents';
$lang['btn_subscribe']         = 'Subscriure\'s a la pàgina';
$lang['btn_profile']           = 'Actualisar perfil';
$lang['btn_reset']             = 'Reiniciar';
$lang['btn_draft']             = 'Editar borrador';
$lang['btn_recover']           = 'Recuperar borrador';
$lang['btn_draftdel']          = 'Borrar borrador';
$lang['btn_revert']            = 'Recuperar';
$lang['btn_register']          = 'Registrar-se';
$lang['loggedinas']            = 'Sessió de:';
$lang['user']                  = 'Nom d\'usuari';
$lang['pass']                  = 'Contrasenya';
$lang['newpass']               = 'Contrasenya nova';
$lang['oldpass']               = 'Confirmar la contrasenya actual';
$lang['passchk']               = 'una atra volta';
$lang['remember']              = 'Recorda\'m';
$lang['fullname']              = 'Nom complet';
$lang['email']                 = 'Correu electrònic';
$lang['profile']               = 'Perfil d\'usuari';
$lang['badlogin']              = 'Disculpe, pero el nom d\'usuari o la contrasenya són incorrectes.';
$lang['minoredit']             = 'Canvis menors';
$lang['draftdate']             = 'Borrador gravat el';
$lang['nosecedit']             = 'La pàgina ha canviat mentres tant, l\'informació de la secció no estava al dia, s\'ha carregat la pàgina sancera.';
$lang['searchcreatepage']      = 'Si no ha trobat lo que buscava pot crear o editar una pàgina en el mateix nom que el text que ha buscat utilisant el botó corresponent.';
$lang['regmissing']            = 'Disculpe, pero deu omplir tots els camps.';
$lang['reguexists']            = 'Disculpe, pero ya existix un usuari en este nom.';
$lang['regsuccess']            = 'S\'ha creat l\'usuari i se li ha enviat la contrasenya per correu electrònic.';
$lang['regsuccess2']           = 'S\'ha creat l\'usuari.';
$lang['regmailfail']           = 'Pareix que ha hagut un erro enviant el correu en la contrasenya. ¡Per favor, contacte en l\'administrador!';
$lang['regbadmail']            = 'La direcció de correu no pareix vàlida - contacte en l\'administrador si pensa que és deu a un erro nostre';
$lang['regbadpass']            = 'Les dos contrasenyes que ha donat no són idèntiques, per favor, torne a intentar-ho.';
$lang['regpwmail']             = 'La seua contrasenya de DokuWiki';
$lang['reghere']               = '¿Encara no té un conte? Cree-se\'n un';
$lang['profna']                = 'Este wiki no li permet modificar el perfil';
$lang['profnochange']          = 'Sense canvis, no hi ha res que fer.';
$lang['profnoempty']           = 'No es permet deixar el nom o la direcció de correu buits.';
$lang['profchanged']           = 'Perfil de l\'usuari actualisat.';
$lang['pwdforget']             = '¿Ha oblidat la contrasenya? Demane\'n una nova';
$lang['resendna']              = 'Este wiki no permet reenviar la contrasenya.';
$lang['resendpwdmissing']      = 'Disculpe, pero deu omplir tots els camps.';
$lang['resendpwdnouser']       = 'Disculpe, pero no trobem ad est usuari en la base de senyes.';
$lang['resendpwdbadauth']      = 'Disculpe, pero este còdic d\'autenticació no es vàlit. Verifique que haja utilisat el víncul de confirmació sancer.';
$lang['resendpwdconfirm']      = 'Li hem enviat un víncul de confirmació al correu.';
$lang['resendpwdsuccess']      = 'Se li ha enviat una nova contrasenya per correu electrònic.';
$lang['license']               = 'Excepte quan s\'indique una atra cosa, el contingut d\'este wiki està llicenciat baix la següent llicència:';
$lang['licenseok']             = 'Nota: a l\'editar esta pàgina accepta llicenciar el seu contingut baix la següent llicència:';
$lang['searchmedia']           = 'Buscar nom d\'archiu:';
$lang['searchmedia_in']        = 'Buscar en %s';
$lang['txt_upload']            = 'Seleccione l\'archiu que vol pujar:';
$lang['txt_filename']          = 'Enviar com (opcional):';
$lang['txt_overwrt']           = 'Sobreescriure archius existents';
$lang['lockedby']              = 'Actualment bloquejat per:';
$lang['lockexpire']            = 'El bloqueig venç a les:';
$lang['js']['willexpire']            = 'El seu bloqueig per a editar esta pàgina vencerà en un minut.\nPer a evitar conflictes utilise el botó de vista prèvia i reiniciarà el contador.';
$lang['js']['notsavedyet']     = 'Els canvis no guardats es perdran.\n¿Segur que vol continuar?';
$lang['rssfailed']             = 'Ha ocorregut un erro al solicitar este canal: ';
$lang['nothingfound']          = 'No s\'ha trobat res.';
$lang['mediaselect']           = 'Archius de mijos';
$lang['uploadsucc']            = 'Enviament correcte';
$lang['uploadfail']            = 'Enviament fallit. ¿Potser no tinga els permissos necessaris?';
$lang['uploadwrong']           = 'Enviament denegat. ¡Esta extensió d\'archiu està prohibida!';
$lang['uploadexist']           = 'L\'archiu ya existix. No s\'ha fet res.';
$lang['uploadbadcontent']      = 'El contingut enviat no coincidix en l\'extensió de l\'archiu %s';
$lang['uploadspam']            = 'L\'enviament ha segut bloquejat per la llista anti-spam.';
$lang['uploadxss']             = 'L\'enviament ha segut bloquejat per ser possiblement perillós.';
$lang['uploadsize']            = 'L\'archiu enviat és massa gran. (màx. %s)';
$lang['deletesucc']            = 'S\'ha borrat l\'archiu "%s".';
$lang['deletefail']            = 'No s\'ha pogut borrar "%s" - comprove els permissos.';
$lang['mediainuse']            = 'L\'archiu "%s" no s\'ha borrat - encara s\'està utilisant.';
$lang['namespaces']            = 'Espais de noms';
$lang['mediafiles']            = 'Archius disponibles en';
$lang['js']['searchmedia']     = 'Buscar archius';
$lang['js']['keepopen']        = 'Mantindre la finestra oberta al seleccionar';
$lang['js']['hidedetails']     = 'Ocultar detalls';
$lang['js']['nosmblinks']      = 'Els vínculs a recursos compartits de Windows només funcionen en Microsoft Internet Explorer. No obstant, es poden copiar i apegar.';
$lang['js']['linkwiz']         = 'Assistent de vínculs';
$lang['js']['linkto']          = 'Vincular a:';
$lang['js']['del_confirm']     = '¿Realment vol borrar el(s) ítem(s) seleccionat(s)?';
$lang['mediausage']            = 'Utilise la següent sintaxis per a referenciar est archiu:';
$lang['mediaview']             = 'Vore l\'archiu original';
$lang['mediaroot']             = 'base';
$lang['mediaupload']           = 'Enviar un archiu a l\'espai de noms actual. Per a crear sub-espais, afigga\'ls separats per dos punts davant del nom de l\'archiu que pose en "Enviar com".';
$lang['mediaextchange']        = '¡Extensió de l\'archiu canviada de .%s a .%s!';
$lang['reference']             = 'Referències per a';
$lang['ref_inuse']             = 'No es pot borrar l\'archiu perque encara s\'utilisa en les següents pàgines:';
$lang['ref_hidden']            = 'Algunes referències estan en pàgines que no té permissos per a vore';
$lang['hits']                  = 'Encerts';
$lang['quickhits']             = 'Noms de pàgines coincidents';
$lang['toc']                   = 'Taula de continguts';
$lang['current']               = 'Actual';
$lang['yours']                 = 'La seua versió';
$lang['diff']                  = 'Mostrar diferències en la versió actual';
$lang['diff2']                 = 'Mostrar diferències entre versions';
$lang['line']                  = 'Llínea';
$lang['breadcrumb']            = 'Traça:';
$lang['youarehere']            = 'Vosté està ací:';
$lang['lastmod']               = 'Última modificació el:';
$lang['by']                    = 'per';
$lang['deleted']               = 'borrat';
$lang['created']               = 'creat';
$lang['restored']              = 'restaurada l\'última versió (%s)';
$lang['external_edit']         = 'edició externa';
$lang['summary']               = 'Editar sumari';
$lang['noflash']               = 'Necessita el <a href="http://www.adobe.com/products/flashplayer/">plúgin d\'Adobe Flash</a> per a vore este contingut.';
$lang['download']              = 'Descarregar un tros';
$lang['mail_newpage']          = 'pàgina afegida:';
$lang['mail_changed']          = 'pàgina canviada:';
$lang['mail_new_user']         = 'Usuari nou:';
$lang['mail_upload']           = 'archiu enviat:';
$lang['qb_bold']               = 'Negreta';
$lang['qb_italic']             = 'Itàlica';
$lang['qb_underl']             = 'Subrallat';
$lang['qb_code']               = 'Còdic';
$lang['qb_strike']             = 'Tachat';
$lang['qb_h1']                 = 'Titular de nivell 1';
$lang['qb_h2']                 = 'Titular de nivell 2';
$lang['qb_h3']                 = 'Titular de nivell 3';
$lang['qb_h4']                 = 'Titular de nivell 4';
$lang['qb_h5']                 = 'Titular de nivell 5';
$lang['qb_h']                  = 'Titular';
$lang['qb_hs']                 = 'Triar titular';
$lang['qb_hplus']              = 'Titular superior';
$lang['qb_hminus']             = 'Titular inferior';
$lang['qb_hequal']             = 'Titular al mateix nivell';
$lang['qb_link']               = 'Víncul intern';
$lang['qb_extlink']            = 'Víncul extern';
$lang['qb_hr']                 = 'Llínea horisontal';
$lang['qb_ol']                 = 'Llista numerada';
$lang['qb_ul']                 = 'Llista ';
$lang['qb_media']              = 'Afegir imàgens i atres archius';
$lang['qb_sig']                = 'Afegir firma';
$lang['qb_smileys']            = 'Smileys';
$lang['qb_chars']              = 'Caràcters especials';
$lang['upperns']               = 'anar a l\'espai de noms superior';
$lang['metaedit']              = 'Editar meta-senyes';
$lang['metasaveerr']           = 'Erro escrivint meta-senyes';
$lang['metasaveok']            = 'Meta-senyes guardades';
$lang['btn_img_backto']        = 'Tornar a %s';
$lang['img_title']             = 'Títul:';
$lang['img_caption']           = 'Subtítul:';
$lang['img_date']              = 'Data:';
$lang['img_fname']             = 'Nom de l\'archiu:';
$lang['img_fsize']             = 'Tamany:';
$lang['img_artist']            = 'Fotógraf:';
$lang['img_copyr']             = 'Copyright:';
$lang['img_format']            = 'Format:';
$lang['img_camera']            = 'Càmara:';
$lang['img_keywords']          = 'Paraules clau:';
$lang['authtempfail']          = 'L\'autenticació d\'usuaris està desactivada temporalment. Si la situació persistix, per favor, informe a l\'administrador del Wiki.';
$lang['i_chooselang']          = 'Trie l\'idioma';
$lang['i_installer']           = 'Instalador de DokuWiki';
$lang['i_wikiname']            = 'Nom del Wiki';
$lang['i_enableacl']           = 'Activar ACL (recomanat)';
$lang['i_superuser']           = 'Super-usuari';
$lang['i_problems']            = 'L\'instalador ha trobat els problemes mostrats més avall. No pot continuar fins que no els arregle.';
$lang['i_modified']            = 'Per raons de seguritat, este procés només funcionarà en una instalació nova i verge de DokuWiki.
Deuria tornar a extraure els archius del paquet que ha descarregat o consultar les
<a href="http://dokuwiki.org/install">instruccions d\'instalació de Dokuwiki</a> completes';
$lang['i_funcna']              = 'La funció de PHP <code>%s</code> no està disponible. ¿Pot ser que el seu proveïdor d\'hostage l\'haja desactivada per algun motiu?';
$lang['i_phpver']              = 'La versió de PHP <code>%s</code> és menor que
la <code>%s</code> que es necessita. Necessita actualisar PHP.';
$lang['i_permfail']            = 'DokuWiki no pot escriure en <code>%s</code>. ¡Necessita arreglar els permissos d\'este directori!';
$lang['i_confexists']          = '<code>%s</code> ya existix';
$lang['i_writeerr']            = 'No es pot crear <code>%s</code>. Haurà de comprovar els permissos del directori/archiu i crear manualment l\'archiu.';
$lang['i_badhash']             = 'dokuwiki.php substituït o modificat (hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - valor illegal o buit';
$lang['i_success']             = 'La configuració ha finalisat correctament. Ya pot borrar l\'archiu install.php. Passe al
<a href="doku.php?id=wiki:welcome">nou DokuWiki</a>.';
$lang['i_failure']             = 'Han aparegut alguns erros escrivint els archius de configuració. Deurà arreglar-los manualment abans de que
puga utilisar el <a href="doku.php?id=wiki:welcome">nou DokuWiki</a>.';
$lang['i_policy']              = 'Política inicial ACL';
$lang['i_pol0']                = 'Wiki obert (llegir, escriure i enviar tots)';
$lang['i_pol1']                = 'Wiki públic (llegir tots, escriure i enviar només usuaris registrats)';
$lang['i_pol2']                = 'Wiki tancat (llegir, escriure i enviar només usuaris registrats)';
$lang['i_retry']               = 'Reintentar';
$lang['recent_global']         = 'Està veent els canvis dins de l\'espai de noms <b>%s</b>. També pot <a href="%s">vore els canvis recents en el wiki sancer</a>.';
$lang['years']                 = 'fa %d anys';
$lang['months']                = 'fa %d mesos';
$lang['weeks']                 = 'fa %d semanes';
$lang['days']                  = 'fa %d dies';
$lang['hours']                 = 'fa %d hores';
$lang['minutes']               = 'fa %d minuts';
$lang['seconds']               = 'fa %d segons';
$lang['email_signature_text'] = 'Este correu ha segut generat per DokuWiki en
@DOKUWIKIURL@';
